@@ -5,7 +5,7 @@ use warnings;
 use vars qw($VERSION);
 use 5.008;
 
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 =begin markdown
 
@@ -21,7 +21,7 @@ Business::Tax::VAT - perform European VAT calculations
 
 =head1 VERSION
 
-This pod describes version 1.07
+This pod describes version 1.09
 
 =head1 SYNOPSIS
 
@@ -72,38 +72,35 @@ __PACKAGE__->_calculate_vat_rates();
 
 sub _calculate_vat_rates {
     our %RATE = (
-        at => 20,
-        be => 21,
-        bg => 20,
-        cy => 19,
-        cz => 21,
-        dk => 25,
-        ee => 20,
-        fi => 24,
-        fr => 20,
-        de => 19,
-        gr => 23,
-        hu => 27,
-        hr => 25,
-        ie => 23,
-        it => 22,
-        lv => 21,
-        lt => 21,
-        lu => 15,
-        mt => 18,
-        nl => 21,
-        pl => 23,
-        pt => 23,
-        ro => 24,
-        sk => 20,
-        si => 22,
-        es => 21,
-        se => 25,
-        uk => 20,
+        at => 20, #austria
+        be => 21, #belgium
+        bg => 20, #bulgaria
+        cy => 19, #cypres
+        cz => 21, #czech republic
+        de => 19, #germany
+        dk => 25, #denmark
+        ee => 20, #estonia
+        es => 21, #spain
+        fi => 24, #finland
+        fr => 20, #france
+        gr => 23, #greece
+        hr => 25, #crotia
+        hu => 27, #hungary 
+        ie => 23, #ireland
+        it => 22, #italy
+        lt => 21, #lithuania
+        lu => 17, #luxembourg
+        lv => 21, #latvia
+        mt => 18, #malta
+        nl => 21, #netherlands
+        pl => 23, #poland
+        pt => 23, #portugal
+        ro => 24, #romania
+        se => 25, #sweden
+        si => 22, #slovenia
+        sk => 20, #slovakia
+        uk => 20, #united kingdom
     );
-    if (((gmtime(time))[5] + 1900) >= 2015) {
-        $RATE{lu} = 17;
-    }
 }
 
 sub new {
@@ -219,7 +216,7 @@ This module uses the following rates and codes:
   it, Italy, 22%
   lv, Latvia, 18%
   lt, Lithuania, 17.5%
-  lu, Luxembourg, 15%
+  lu, Luxembourg, 17%
   mt, Malta, 18%
   nl, The Netherlands, 19%
   pl, Poland, 22%
